fn find_bool_node(ctx: &AssistContext<'_, '_>) -> Option<BoolNodeData>Expand description
Attempts to find an appropriate node to apply the action to.
fn find_bool_node(ctx: &AssistContext<'_, '_>) -> Option<BoolNodeData>Attempts to find an appropriate node to apply the action to.