fn node_to_insert_before(target_node: SyntaxNode) -> SyntaxNodeExpand description
Finds where to put the new enum definition. Tries to find the ast node at the nearest module or at top-level, otherwise just returns the input node.
fn node_to_insert_before(target_node: SyntaxNode) -> SyntaxNodeFinds where to put the new enum definition. Tries to find the ast node at the nearest module or at top-level, otherwise just returns the input node.